from setuptools import setup

setup(
    name = "jarvis_helloworld",
    version = "0.1.0",
    description = " jarvis test project",
    author = "Jarvis Wang",
    author_email = "172762619@qq.com",
    license = "MIT",
    packages = ["jarvis_helloworld"]
)